@@ -31,11 +31,28 @@ import collections.abc
 import copy
 import importlib.util
 import inspect
+import os
 import sys
 import traceback
 import types
 import warnings
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Mapping, Optional, Type, TypeVar, Union
+from pathlib import Path
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Awaitable,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Mapping,
+    Optional,
+    Sequence,
+    Type,
+    TypeVar,
+    Union,
+)
 
 import nextcord
 
@@ -49,6 +66,12 @@ from .view import StringView
 if TYPE_CHECKING:
     import importlib.machinery
 
+    import aiohttp
+
+    from nextcord.activity import BaseActivity
+    from nextcord.enums import Status
+    from nextcord.flags import MemberCacheFlags
+    from nextcord.mentions import AllowedMentions
     from nextcord.message import Message
     from nextcord.types.checks import ApplicationCheck, ApplicationHook
 
@@ -120,14 +143,6 @@ def _is_submodule(parent: str, child: str) -> bool:
     return parent == child or child.startswith(parent + ".")
 
 
-class _DefaultRepr:
-    def __repr__(self):
-        return "<default-help-command>"
-
-
-_default = _DefaultRepr()
-
-
 class MissingMessageContentIntentWarning(UserWarning):
     """Warning category raised when instantiating a :class:`~nextcord.ext.commands.Bot` with a
     :attr:`~nextcord.ext.commands.Bot.command_prefix` but without the :attr:`~nextcord.Intents.message_content`
@@ -149,9 +164,31 @@ class MissingMessageContentIntentWarning(UserWarning):
     pass
 
 
+_NonCallablePrefix = Union[str, Sequence[str]]
+
+
 class BotBase(GroupMixin):
-    def __init__(self, command_prefix=MISSING, help_command=_default, description=None, **options):
-        super().__init__(**options)
+    def __init__(
+        self,
+        command_prefix: Union[
+            _NonCallablePrefix,
+            Callable[
+                [Union[Bot, AutoShardedBot], Message],
+                Union[Awaitable[_NonCallablePrefix], _NonCallablePrefix],
+            ],
+        ],
+        help_command: Optional[HelpCommand],
+        description: Optional[str],
+        *,
+        owner_id: Optional[int],
+        owner_ids: Optional[Iterable[int]],
+        strip_after_prefix: bool,
+        case_insensitive: bool,
+    ):
+        super().__init__(
+            case_insensitive=case_insensitive,
+        )
+
         self.command_prefix = command_prefix if command_prefix is not MISSING else tuple()
         self.extra_events: Dict[str, List[CoroFunc]] = {}
         self.__cogs: Dict[str, Cog] = {}
@@ -160,11 +197,11 @@ class BotBase(GroupMixin):
         self._check_once = []
         self._before_invoke = None
         self._after_invoke = None
-        self._help_command = None
+        self._help_command: Optional[HelpCommand] = None
         self.description = inspect.cleandoc(description) if description else ""
-        self.owner_id = options.get("owner_id")
-        self.owner_ids = options.get("owner_ids", set())
-        self.strip_after_prefix = options.get("strip_after_prefix", False)
+        self.owner_id = owner_id
+        self.owner_ids = owner_ids or set()
+        self.strip_after_prefix = strip_after_prefix
 
         if self.owner_id and self.owner_ids:
             raise TypeError("Both owner_id and owner_ids are set.")
@@ -193,7 +230,7 @@ class BotBase(GroupMixin):
                 stacklevel=0,
             )
 
-        if help_command is _default:
+        if help_command is MISSING:
             self.help_command = DefaultHelpCommand()
         else:
             self.help_command = help_command
@@ -806,7 +843,7 @@ class BotBase(GroupMixin):
             Usage ::
 
                 # main.py
-                bot.load_extensions("cogs.me_cog", extras={"keyword_arg": True})
+                bot.load_extension("cogs.me_cog", extras={"keyword_arg": True})
 
                 # cogs/me_cog.py
                 class MeCog(commands.Cog):
@@ -954,6 +991,231 @@ class BotBase(GroupMixin):
             sys.modules.update(modules)
             raise
 
+    def load_extensions(
+        self,
+        names: List[str],
+        *,
+        package: Optional[str] = None,
+        packages: Optional[List[str]] = None,
+        extras: Optional[List[Dict[str, Any]]] = None,
+        stop_at_error: bool = False,
+    ) -> List[str]:
+        """Loads all extensions provided in a list.
+
+        .. note::
+
+            By default, any exceptions found while loading will not be raised but will be printed to console (standard error/`stderr`).
+
+        .. versionadded:: 2.1
+
+        Parameters
+        ----------
+        names: List[:class:`str`]
+            The names of all of the extensions to load.
+        package: Optional[:class:`str`]
+            The package name to resolve relative imports with.
+            This is required when loading an extension using a relative path, e.g ``.foo.test``.
+            Defaults to ``None``.
+        packages: Optional[List[:class:`str`]]
+            A list of package names to resolve relative imports with.
+            This is required when loading an extension using a relative path, e.g ``.foo.test``.
+            Defaults to ``None``.
+
+            Usage::
+
+                # main.py
+                bot.load_extensions(
+                    [
+                        ".my_cog",
+                        ".my_cog_two",
+                    ],
+                    packages=[
+                        "cogs.coolcog",
+                        "cogs.coolcogtwo",
+                    ],
+                )
+
+                # cogs/coolcog/my_cog.py
+                class MyCog(commands.Cog):
+                    def __init__(self, bot):
+                        self.bot = bot
+
+                    # ...
+
+                def setup(bot):
+                    bot.add_cog(MyCog(bot))
+
+                # cogs/coolcogtwo/my_cog_two.py
+                class MyCogTwo(commands.Cog):
+                    def __init__(self, bot):
+                        self.bot = bot
+
+                    # ...
+
+                def setup(bot):
+                    bot.add_cog(MyCogTwo(bot))
+
+        extras: Optional[List[Dict[:class:`str`, Any]]]
+            A list of extra arguments to pass to the extension's setup function.
+
+            Usage::
+
+                # main.py
+                bot.load_extensions(
+                    [
+                        ".my_cog",
+                        ".my_cog_two",
+                    ],
+                    package="cogs",
+                    extras=[{"my_attribute": 11}, {"my_other_attribute": 12}],
+                )
+
+                # cogs/my_cog.py
+                class MyCog(commands.Cog):
+                    def __init__(self, bot, my_attribute):
+                        self.bot = bot
+                        self.my_attribute = my_attribute
+
+                    # ...
+
+                def setup(bot, **kwargs):
+                    bot.add_cog(MyCog(bot, **kwargs))
+
+                # cogs/my_cog_two.py
+                class MyCogTwo(commands.Cog):
+                    def __init__(self, bot, my_other_attribute):
+                        self.bot = bot
+                        self.my_other_attribute = my_other_attribute
+
+                    # ...
+
+                def setup(bot, my_other_attribute):
+                    bot.add_cog(MyCogTwo(bot, my_other_attribute))
+
+        stop_at_error: :class:`bool`
+            Whether or not an exception should be raised if we encounter one. Set to ``False`` by
+            default.
+
+        Returns
+        -------
+        List[:class:`str`]
+            A list that contains the names of all of the extensions
+            that loaded successfully.
+
+        Raises
+        ------
+        ValueError
+            The length of ``packages`` or the length of ``extras` is not equal to the length of ``names``.
+        InvalidArgument
+            You passed in both ``package`` and ``packages``.
+        ExtensionNotFound
+            An extension could not be imported.
+        ExtensionAlreadyLoaded
+            An extension is already loaded.
+        NoEntryPointError
+            An extension does not have a setup function.
+        ExtensionFailed
+            An extension or its setup function had an execution error.
+        """
+        if package and packages:
+            raise errors.BadArgument("Cannot provide both package and packages.")
+        if packages and len(packages) != len(names):
+            raise ValueError("The length of packages must match the length of extensions.")
+        if extras and len(extras) != len(names):
+            raise ValueError("The length of extra parameters must match the length of extensions.")
+
+        packages_itr: Optional[Iterator] = iter(packages) if packages else None
+        extras_itr: Optional[Iterator] = iter(extras) if extras else None
+
+        loaded_extensions: List[str] = []
+
+        for extension in names:
+            if packages_itr:
+                package = next(packages_itr)
+            cur_extra: Optional[Dict[str, Any]] = next(extras_itr) if extras_itr else None
+
+            try:
+                self.load_extension(extension, package=package, extras=cur_extra)
+            except Exception as e:
+                if stop_at_error:
+                    raise e
+                else:
+                    # we print the exception instead of raising it because we want to continue loading extensions
+                    traceback.print_exception(type(e), e, e.__traceback__, file=sys.stderr)
+            else:
+                loaded_extensions.append(extension)
+
+        return loaded_extensions
+
+    def load_extensions_from_module(
+        self, source_module: str, *, ignore: Optional[List[str]] = None, stop_at_error: bool = False
+    ) -> List[str]:
+        """Loads all extensions found in a module.
+
+        Once an extension found in a module has been loaded and did not throw
+        any exceptions, it will be added to a list of extension names that
+        will be returned.
+
+        .. note::
+
+            By default, any exceptions found while loading will not be raised but will be printed to console (standard error/`stderr`).
+
+        .. versionadded:: 2.1
+
+        Parameters
+        ----------
+        source_module: :class:`str`
+            The name of the source module to look for submodules.
+        ignore: Optional[List[:class:`str`]]
+            File names of extensions to ignore.
+        stop_at_error: :class:`bool`
+            Whether or not an exception should be raised if we encounter one. Set to ``False`` by
+            default.
+
+        Returns
+        -------
+        List[:class:`str`]
+            A list that contains the names of all of the extensions
+            that loaded successfully.
+
+        Raises
+        ------
+        ValueError
+            The module at ``source_module`` is not found, or the module at ``source_module``
+            has no submodules.
+        ExtensionNotFound
+            An extension could not be imported.
+        ExtensionAlreadyLoaded
+            An extension is already loaded.
+        NoEntryPointError
+            An extension does not have a setup function.
+        ExtensionFailed
+            An extension or its setup function had an execution error.
+        """
+        name = self._resolve_name(source_module, None)
+        spec = importlib.util.find_spec(name)
+        if spec is None:
+            raise ValueError(f"Module {name} not found")
+
+        submodule_paths = spec.submodule_search_locations
+        if submodule_paths is None:
+            raise ValueError(f"Module {name} has no submodules")
+
+        extensions: List[str] = []
+
+        for submodule_path in submodule_paths:
+            submodules = [
+                (f"{name}.{submodule[:-3]}" if submodule.endswith(".py") else f"{name}.{submodule}")
+                for submodule in os.listdir(submodule_path)
+                if not submodule.startswith("_")
+            ]
+            if ignore is not None:
+                submodules = [s for s in submodules if s not in ignore]
+
+            extensions.extend(self.load_extensions(submodules, stop_at_error=stop_at_error))
+
+        return extensions
+
     @property
     def extensions(self) -> Mapping[str, types.ModuleType]:
         """Mapping[:class:`str`, :class:`py:types.ModuleType`]: A read-only mapping of extension name to extension."""
@@ -999,9 +1261,12 @@ class BotBase(GroupMixin):
             A list of prefixes or a single prefix that the bot is
             listening for.
         """
-        prefix = ret = self.command_prefix
+        prefix = self.command_prefix
         if callable(prefix):
-            ret = await nextcord.utils.maybe_coroutine(prefix, self, message)
+            ret = await nextcord.utils.maybe_coroutine(prefix, self, message)  # type: ignore
+            # the callable wants an (AutoSharded)Bot but this is BotBase
+        else:
+            ret = prefix
 
         if not isinstance(ret, str):
             try:
@@ -1122,7 +1387,7 @@ class BotBase(GroupMixin):
             else:
                 self.dispatch("command_completion", ctx)
         elif ctx.invoked_with:
-            exc = errors.CommandNotFound(f'Command "{ctx.invoked_with}" is not found')
+            exc = errors.CommandNotFound(ctx.invoked_with)
             self.dispatch("command_error", ctx, exc)
 
     async def process_commands(self, message: Message) -> None:
@@ -1349,7 +1614,85 @@ class Bot(BotBase, nextcord.Client):
         .. versionadded:: 1.7
     """
 
-    pass
+    def __init__(
+        self,
+        command_prefix: Union[
+            _NonCallablePrefix,
+            Callable[
+                [Union[Bot, AutoShardedBot], Message],
+                Union[Awaitable[_NonCallablePrefix], _NonCallablePrefix],
+            ],
+        ] = tuple(),
+        help_command: Optional[HelpCommand] = MISSING,
+        description: Optional[str] = None,
+        *,
+        max_messages: Optional[int] = 1000,
+        connector: Optional[aiohttp.BaseConnector] = None,
+        proxy: Optional[str] = None,
+        proxy_auth: Optional[aiohttp.BasicAuth] = None,
+        shard_id: Optional[int] = None,
+        shard_count: Optional[int] = None,
+        application_id: Optional[int] = None,
+        intents: nextcord.Intents = nextcord.Intents.default(),
+        member_cache_flags: MemberCacheFlags = MISSING,
+        chunk_guilds_at_startup: bool = MISSING,
+        status: Optional[Status] = None,
+        activity: Optional[BaseActivity] = None,
+        allowed_mentions: Optional[AllowedMentions] = None,
+        heartbeat_timeout: float = 60.0,
+        guild_ready_timeout: float = 2.0,
+        assume_unsync_clock: bool = True,
+        enable_debug_events: bool = False,
+        loop: Optional[asyncio.AbstractEventLoop] = None,
+        lazy_load_commands: bool = True,
+        rollout_associate_known: bool = True,
+        rollout_delete_unknown: bool = True,
+        rollout_register_new: bool = True,
+        rollout_update_known: bool = True,
+        rollout_all_guilds: bool = False,
+        owner_id: Optional[int] = None,
+        owner_ids: Optional[Iterable[int]] = None,
+        strip_after_prefix: bool = False,
+        case_insensitive: bool = False,
+    ):
+        nextcord.Client.__init__(
+            self,
+            max_messages=max_messages,
+            connector=connector,
+            proxy=proxy,
+            proxy_auth=proxy_auth,
+            shard_id=shard_id,
+            shard_count=shard_count,
+            application_id=application_id,
+            intents=intents,
+            member_cache_flags=member_cache_flags,
+            chunk_guilds_at_startup=chunk_guilds_at_startup,
+            status=status,
+            activity=activity,
+            allowed_mentions=allowed_mentions,
+            heartbeat_timeout=heartbeat_timeout,
+            guild_ready_timeout=guild_ready_timeout,
+            assume_unsync_clock=assume_unsync_clock,
+            enable_debug_events=enable_debug_events,
+            loop=loop,
+            lazy_load_commands=lazy_load_commands,
+            rollout_associate_known=rollout_associate_known,
+            rollout_delete_unknown=rollout_delete_unknown,
+            rollout_register_new=rollout_register_new,
+            rollout_update_known=rollout_update_known,
+            rollout_all_guilds=rollout_all_guilds,
+        )
+
+        BotBase.__init__(
+            self,
+            command_prefix=command_prefix,
+            help_command=help_command,
+            description=description,
+            owner_id=owner_id,
+            owner_ids=owner_ids,
+            strip_after_prefix=strip_after_prefix,
+            case_insensitive=case_insensitive,
+        )
 
 
 class AutoShardedBot(BotBase, nextcord.AutoShardedClient):
@@ -1357,4 +1700,84 @@ class AutoShardedBot(BotBase, nextcord.AutoShardedClient):
     :class:`nextcord.AutoShardedClient` instead.
     """
 
-    pass
+    def __init__(
+        self,
+        command_prefix: Union[
+            _NonCallablePrefix,
+            Callable[
+                [Union[Bot, AutoShardedBot], Message],
+                Union[Awaitable[_NonCallablePrefix], _NonCallablePrefix],
+            ],
+        ] = tuple(),
+        help_command: Optional[HelpCommand] = MISSING,
+        description: Optional[str] = None,
+        *,
+        max_messages: Optional[int] = 1000,
+        connector: Optional[aiohttp.BaseConnector] = None,
+        proxy: Optional[str] = None,
+        proxy_auth: Optional[aiohttp.BasicAuth] = None,
+        shard_id: Optional[int] = None,
+        shard_count: Optional[int] = None,
+        shard_ids: Optional[list[int]] = None,
+        application_id: Optional[int] = None,
+        intents: nextcord.Intents = nextcord.Intents.default(),
+        member_cache_flags: MemberCacheFlags = MISSING,
+        chunk_guilds_at_startup: bool = MISSING,
+        status: Optional[Status] = None,
+        activity: Optional[BaseActivity] = None,
+        allowed_mentions: Optional[AllowedMentions] = None,
+        heartbeat_timeout: float = 60.0,
+        guild_ready_timeout: float = 2.0,
+        assume_unsync_clock: bool = True,
+        enable_debug_events: bool = False,
+        loop: Optional[asyncio.AbstractEventLoop] = None,
+        lazy_load_commands: bool = True,
+        rollout_associate_known: bool = True,
+        rollout_delete_unknown: bool = True,
+        rollout_register_new: bool = True,
+        rollout_update_known: bool = True,
+        rollout_all_guilds: bool = False,
+        owner_id: Optional[int] = None,
+        owner_ids: Optional[Iterable[int]] = None,
+        strip_after_prefix: bool = False,
+        case_insensitive: bool = False,
+    ):
+        nextcord.AutoShardedClient.__init__(
+            self,
+            max_messages=max_messages,
+            connector=connector,
+            proxy=proxy,
+            proxy_auth=proxy_auth,
+            shard_id=shard_id,
+            shard_count=shard_count,
+            shard_ids=shard_ids,
+            application_id=application_id,
+            intents=intents,
+            member_cache_flags=member_cache_flags,
+            chunk_guilds_at_startup=chunk_guilds_at_startup,
+            status=status,
+            activity=activity,
+            allowed_mentions=allowed_mentions,
+            heartbeat_timeout=heartbeat_timeout,
+            guild_ready_timeout=guild_ready_timeout,
+            assume_unsync_clock=assume_unsync_clock,
+            enable_debug_events=enable_debug_events,
+            loop=loop,
+            lazy_load_commands=lazy_load_commands,
+            rollout_associate_known=rollout_associate_known,
+            rollout_delete_unknown=rollout_delete_unknown,
+            rollout_register_new=rollout_register_new,
+            rollout_update_known=rollout_update_known,
+            rollout_all_guilds=rollout_all_guilds,
+        )
+
+        BotBase.__init__(
+            self,
+            command_prefix=command_prefix,
+            help_command=help_command,
+            description=description,
+            owner_id=owner_id,
+            owner_ids=owner_ids,
+            strip_after_prefix=strip_after_prefix,
+            case_insensitive=case_insensitive,
+        )
